@@ -3,7 +3,7 @@ package Pod::Weaver::PluginBundle::DROLSKY;
 use strict;
 use warnings;
 
-our $VERSION = '0.66';
+our $VERSION = '0.67';
 
 use namespace::autoclean -also => ['_exp'];
 
@@ -45,7 +45,7 @@ sub configure {
         };
 
     my $zilla          = $podweaver_plugin->zilla;
-    my $license_plugin = $zilla->plugin_named('@Author::DROLSKY/License');
+    my $license_plugin = $zilla->plugin_named('@DROLSKY/License');
     my $license_filename
         = $license_plugin ? $license_plugin->filename : 'LICENSE';
 
@@ -53,13 +53,12 @@ sub configure {
     my $include_donations = $zilla->copyright_holder =~ /Rolsky/
         && $config->include_donations_pod;
 
-    return (
+    my @config = (
         '@CorePrep',
-        '-SingleEncoding',
+        [ '-SingleEncoding' => { encoding => 'UTF-8' } ],
         [ '-Transformer' => List     => { transformer => 'List' } ],
         [ '-Transformer' => Verbatim => { transformer => 'Verbatim' } ],
-
-        [ 'Region' => 'header' ],
+        [ 'Region'       => 'header' ],
         'Name',
         'Version',
         [ 'Region'  => 'prelude' ],
@@ -72,7 +71,6 @@ sub configure {
         [ 'Collect' => 'TYPES' => { command => 'type' } ],
         'Leftovers',
         [ 'Region' => 'postlude' ],
-
         [
             'GenerateSection' => 'generate SUPPORT' => {
                 title            => 'SUPPORT',
@@ -83,7 +81,7 @@ sub configure {
     ($bugtracker_email && $bugtracker_email =~ /rt\.cpan\.org/)
     ? "Bugs may be submitted through L<the RT bug tracker|$bugtracker_web>\n(or L<$bugtracker_email|mailto:$bugtracker_email>)."
     : $bugtracker_web
-    ? "bugs may be submitted through L<$bugtracker_web>."
+    ? "Bugs may be submitted through L<$bugtracker_web>."
     : (),
 
     $distmeta->{resources}{x_MailingList} ? 'There is a mailing list available for users of this distribution,' . "\nL<mailto:" . $distmeta->{resources}{x_MailingList} . '>.' : (),
@@ -103,14 +101,13 @@ sub configure {
         : (),
 
     ($distmeta->{x_authority} // '') eq 'cpan:DROLSKY'
-    ? "I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>."
+    ? q{I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.}
     : (),
 ) }}
 SUPPORT
                 ]
             },
         ],
-
         [
             'AllowOverride' => 'allow override SUPPORT' => {
                 header_re      => '^(SUPPORT|BUGS)\b',
@@ -118,16 +115,16 @@ SUPPORT
                 match_anywhere => 0,
             },
         ],
+    );
 
-        (
-            $include_donations
-            ? [
-                'GenerateSection' => 'generate DONATIONS' => {
-                    title            => 'DONATIONS',
-                    main_module_only => 1,
-                    is_template      => 0,
-                    text             => [
-                        <<'DONATIONS',
+    if ($include_donations) {
+        push @config, [
+            'GenerateSection' => 'generate DONATIONS' => {
+                title            => 'DONATIONS',
+                main_module_only => 1,
+                is_template      => 0,
+                text             => [
+                    <<'DONATIONS',
 If you'd like to thank me for the work I've done on this module, please
 consider making a "donation" to me via PayPal. I spend a lot of free time
 creating free software, and would appreciate any support you'd care to offer.
@@ -143,12 +140,12 @@ on free software full time (let's all have a chuckle at that together).
 To donate, log into PayPal and send money to autarch@urth.org, or use the
 button at L<http://www.urth.org/~autarch/fs-donation.html>.
 DONATIONS
-                    ]
-                },
                 ]
-            : ()
-        ),
+            },
+        ];
+    }
 
+    push @config, (
         'Authors',
         [ 'Contributors' => { ':version' => '0.008' } ],
         [
@@ -159,6 +156,8 @@ DONATIONS
         ],
         [ 'Region' => 'footer' ],
     );
+
+    return @config;
 }
 
 sub mvp_bundle_config {
@@ -215,7 +214,7 @@ sub _expand_config {
 
     use_module( $class, $payload->{':version'} ) if $payload->{':version'};
 
-    # prepend '@Author::DROLSKY/' to each class name,
+    # prepend '@DROLSKY/' to each class name,
     # except for Generic and Collect which are left alone.
     $name = '@' . $self->_prefix . '/' . $name
         if $class ne _exp('Generic')
@@ -240,22 +239,22 @@ Pod::Weaver::PluginBundle::DROLSKY - A plugin bundle for pod woven by DROLSKY
 
 =head1 VERSION
 
-version 0.66
+version 0.67
 
 =head1 SYNOPSIS
 
 In your F<weaver.ini>:
 
-    [@Author::DROLSKY]
+    [@DROLSKY]
 
 Or in your F<dist.ini>
 
     [PodWeaver]
-    config_plugin = @Author::DROLSKY
+    config_plugin = @DROLSKY
 
 It is also used automatically when your F<dist.ini> contains:
 
-    [@Author::DROLSKY]
+    [@DROLSKY]
     :version = 0.094
 
 =head1 DESCRIPTION
@@ -372,14 +371,14 @@ be possible without updates to L<Pod::Weaver>.)
 This F<weaver.ini> will let you use a custom C<COPYRIGHT AND LICENSE> section
 and still use the plugin bundle:
 
-    [@Author::DROLSKY]
+    [@DROLSKY]
     [AllowOverride / OverrideLegal]
     header_re = ^COPYRIGHT
     match_anywhere = 1
 
 =head1 ADDING STOPWORDS FOR SPELLING TESTS
 
-As noted in L<Dist::Zilla::PluginBundle::Author::DROLSKY>, stopwords for
+As noted in L<Dist::Zilla::PluginBundle::DROLSKY>, stopwords for
 spelling tests can be added by adding a directive to pod:
 
     =for stopwords foo bar baz
@@ -410,7 +409,7 @@ L<Dist::Zilla::Plugin::PodWeaver>
 
 =item *
 
-L<Dist::Zilla::PluginBundle::Author::DROLSKY>
+L<Dist::Zilla::PluginBundle::DROLSKY>
 
 =back
 
@@ -425,7 +424,7 @@ I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
